"""Console script for p2_cli."""
import os
import click
import pprint
from tabulate import tabulate
import time
from datetime import date

from p2_cli.p2_cli import Client

p2_store_endpoint = os.environ.get('P2_STORE_URL')

if p2_store_endpoint is None:
    click.echo("P2_STORE_URL not set")
    exit()

pp = pprint.PrettyPrinter(indent=2, width=140)
client = Client( p2_store_endpoint )

@click.group()
def cli():
    pass

@cli.command(help="Lists all experiments ")
def list_experiments(args=None ):
    data = client.list_experiments()
    if data is None: 
        click.echo("Error getting experiments")
    else:
        click.echo("Experiments")
        click.echo('-'*80)
        for experiment in data:
            click.echo(experiment)
    return 0

@cli.command(help="Returns the selected experiment")
@click.option('--filename', required=True, help='the experiment filename')
def get_experiment(filename):
    click.echo("Filename: {}".format(filename))
    click.echo('-'*80)
    data   = client.get_experiment(filename)
    if data is None:
        click.echo("Error retrieving data for experiment {}".format(filename))
    else:
        pp.pprint(data)

@cli.command(help="Retrieves the log for that session/log_type")
@click.option('--exp_id', required=True, help='the experiment id')
@click.option('--log_type', default='1', help='the log type')
def get_exp_log (exp_id, log_type):
    data = client.get_exp_log(exp_id, log_type)
    if data is None:
        click.echo("Error getting experiment {} log".format(exp_id))
    else:
        pp.pprint(data)

@cli.command(help="List of today's planned sessions")
def list_today_sessions():
    today = date.today()
    dom = today.day
    month = today.month
    list_sessions_short([
        "dom:{:02d}".format(today.day),
        "month:{:02d}".format(today.month)
        ])

@cli.command(help="List of yesterday's planned sessions")
def list_yesterday_sessions():
    yesterday = date.fromtimestamp(time.time() - 86400)
    list_sessions_short([
        "dom:{:02d}".format(yesterday.day),
        "month:{:02d}".format(yesterday.month)
        ])

@cli.command(help="List all sessions attributes matching a filter")
@click.argument('filter', nargs=-1)
def list_sessions_long(filter):
    for arg in filter:
        if ':' not in arg:
            click.echo('Filters are "key":"value" pairs')
            exit()
    d = dict(arg.split(':') for arg in filter)
    data = client.get_sessions(filter=d)
    click.echo(tabulate(data, headers='keys'))

@cli.command(help="Lists a few sessions attributes using a filter")
@click.argument('filter', nargs=-1)
def list_sessions_short(filter):
    for arg in filter:
        if ':' not in arg:
            click.echo('Filters are "key":"value" pairs')
            exit()
    d = dict(arg.split(':') for arg in filter)
    data = client.get_sessions(filter=d)
    for exp in data:
        for key in exp.copy():
            if key not in [
                    'exp_id', 
                    'filepath', 
                    'mins',
                    'hour',
                    'dom',
                    'dow',
                    'month',
                    'year',
                    'status']:
                del exp[key]
    click.echo(tabulate(data, headers='keys'))

if __name__ == "__main__":
    cli()
